==> MoNeT_MGDrivE-0.4.4.8.tar.gz: MoNeT_MGDrivE-0.4.4.8/README.md <==
#  Description

This module was created to accompany the [MGDrivE](https://marshalllab.github.io/MGDrivE/) and [MoNeT](https://chipdelmal.github.io/MoNeT/) projects to make the analysis of the spatiotemporal simulations of gene-drive spreads as seamless as possible.

<hr>

#  Project Status

Out code is currently under beta testing by the gene-drive [data analysis team](https://chipdelmal.github.io/MoNeT/Berkeley.html): Biyonka Liang, Gillian Chu, Maya Shen. As well as under intense development by the [dev team](https://chipdelmal.github.io/MoNeT/PythonModule.html): [Héctor M. Sánchez C.](https://chipdelmal.github.io/), Víctor Ferman, and Sarafina Smith.

<hr>

# Common Operations

##  Installation

To install from pypi with pip:

```bash
pip install MoNeT_MGDrivE
```

Alternatively, the package can be downloaded, and installed with:

```bash
pip install .
```

## Anaconda Environment

The anaconda environment containing all the packages necessary to run our analyses scripts is available in [our anaconda cloud website](https://anaconda.org/chipdelmal/monet).
To install it, [download our YML file](https://anaconda.org/chipdelmal/MoNeT/files) and run:

```bash
conda env create -f MoNeT.yml -n MoNeT
```

## Dependencies

* [Numpy](http://www.numpy.org/)
* [Matplotlib](https://matplotlib.org/)
* [Pandas](https://pandas.pydata.org/)

<hr>

#  Authors

* __Lead__: [Héctor M. Sánchez C](https://chipdelmal.github.io/).
* __Dev__: Sarafina Smith, Víctor Ferman, Biyonka Liang
* __Former Dev__: Sabrina Wong
* __PI__: [John M. Marshall](https://www.marshalllab.com/)

==> MoNeT_MGDrivE-0.4.5.5.tar.gz: MoNeT_MGDrivE-0.4.5.5/README.md <==

This module was created to accompany the [MGDrivE](https://marshalllab.github.io/MGDrivE/) and [MoNeT](https://chipdelmal.github.io/MoNeT/) projects to make the analysis of the spatiotemporal simulations of gene-drive spreads as seamless as possible.

It is also meant to serve as a platform to ensure the reproducibility of results of the publications from our [research group at UC, Berkeley](https://www.marshalllab.com/), as part of [DARPA's: Safe Genes program](https://www.darpa.mil/program/safe-genes) and [UCI Malaria  Initiative](http://malaria.bio.uci.edu/).

<hr>

##  Project Status

Out code is currently under beta testing by the gene-drive [data analysis team](https://chipdelmal.github.io/MoNeT/Berkeley.html): Biyonka Liang, Gillian Chu, Maya Shen. As well as under intense development by the [dev team](https://chipdelmal.github.io/MoNeT/PythonModule.html): [Héctor M. Sánchez C.](https://chipdelmal.github.io/), Víctor Ferman, and Sarafina Smith.

For some examples of how this package is being currently used, please follow this [link](https://chipdelmal.github.io/MoNeT/Berkeley.html).

<hr>

##  Installation

It is highly recommended to [download](https://anaconda.org/chipdelmal/MoNeT/files) and install our [anaconda environment](https://anaconda.org/chipdelmal/monet):

```bash
conda env create -f MoNeT.yml -n MoNeT
```

To install from pypi with pip:

```bash
pip install MoNeT-MGDrivE
```

Alternatively, the package can be downloaded, and installed with:

```bash
pip install .
```

Make sure to have the following dependencies installed:

* [Numpy](http://www.numpy.org/)
* [Matplotlib](https://matplotlib.org/)
* [Pandas](https://pandas.pydata.org/)

<hr>

##  Authors

* __Lead__: [Héctor M. Sánchez C](https://chipdelmal.github.io/).
* __Dev__: Sarafina Smith, Víctor Ferman, Biyonka Liang
* __Former Dev__: Sabrina Wong
* __PI__: [John M. Marshall](https://www.marshalllab.com/)
